@@ -13,7 +13,8 @@
 # limitations under the License.
 
 """Ansible inventory output module."""
-
+import logging
+import typing
 from copy import deepcopy
 
 from mrack.errors import ConfigError
@@ -28,7 +29,11 @@ from mrack.utils import (
 )
 
 DEFAULT_INVENTORY_PATH = "mrack-inventory.yaml"
-DEFAULT_INVENTORY_LAYOUT = {"all": {"children": {}, "hosts": {}}}
+DEFAULT_INVENTORY_LAYOUT: typing.Dict[str, typing.Dict] = {
+    "all": {"children": {}, "hosts": {}}
+}
+
+logger = logging.getLogger(__name__)
 
 
 def copy_meta_attrs(host, meta_host, attrs):
@@ -104,12 +109,12 @@ class AnsibleInventoryOutput:
     files and information in DB.
     """
 
-    def __init__(self, config, db, metadata, path=DEFAULT_INVENTORY_PATH):
+    def __init__(self, config, db, metadata, path=None):
         """Init the output module."""
         self._config = config
         self._db = db
         self._metadata = metadata
-        self._path = path
+        self._path = path or DEFAULT_INVENTORY_PATH
 
     def create_ansible_host(self, name):
         """Create host entry for Ansible inventory."""
@@ -148,7 +153,7 @@ class AnsibleInventoryOutput:
         copy_meta_attrs(host_info, meta_host, ["os", "role", "netbios"])
 
         if "parent" in meta_domain:
-            host_info["parent_domain"] = meta_domain["parent"]
+            host_info["meta_parent_domain"] = meta_domain["parent"]
 
         if ssh_key:
             host_info["ansible_ssh_private_key_file"] = ssh_key
@@ -157,6 +162,9 @@ class AnsibleInventoryOutput:
             host_info["ansible_password"] = password
 
         if is_windows_host(meta_host):
+            if "netbios" in meta_host:
+                host_info.update({"meta_netbios": meta_host["netbios"]})
+
             host_info.update(
                 {
                     "ansible_port": 5986,
@@ -165,6 +173,7 @@ class AnsibleInventoryOutput:
                     "meta_domain_level": meta_host.get("domain_level", "top"),
                 }
             )
+
         return host_info
 
     def create_inventory(self):
@@ -200,4 +209,6 @@ class AnsibleInventoryOutput:
         """Create the target output file."""
         inventory = self.create_inventory()
         save_yaml(self._path, inventory)
+        if self._path:
+            logger.info(f"Created: {self._path}")
         return inventory
