@@ -16,19 +16,27 @@
 
 import asyncio
 import logging
+import os
 import sys
 from functools import update_wrapper
 
 import click
 
 from mrack.actions.destroy import Destroy
+from mrack.actions.etchosts import EtcHostsUpdate
 from mrack.actions.list import List
 from mrack.actions.output import Output
 from mrack.actions.ssh import SSH
 from mrack.actions.up import Up
-from mrack.config import ProvisioningConfig
+from mrack.config import MrackConfig, ProvisioningConfig
 from mrack.dbdrivers.file import FileDBDriver
-from mrack.errors import ConfigError, MetadataError, ProviderError, ValidationError
+from mrack.errors import (
+    ApplicationError,
+    ConfigError,
+    MetadataError,
+    ProviderError,
+    ValidationError,
+)
 from mrack.providers import providers
 from mrack.providers.aws import PROVISIONER_KEY as AWS
 from mrack.providers.aws import AWSProvider
@@ -69,44 +77,75 @@ def init_db(path):
 
 
 @no_such_file_config_handler(error="Provisioning config file not found: {path}")
-def init_config(path):
+def init_prov_config(path):
     """Load and initialize provisioning configuration."""
     config_data = load_yaml(path)
     config = ProvisioningConfig(config_data)
     return config
 
 
-@no_such_file_config_handler(error="Job metadata file not found: {path}")
-def init_metadata(path):
+def init_metadata(ctx, user_defined_path):
     """Load and initialize job metadata."""
-    metadata_data = load_yaml(path)
+    config = ctx.obj[CONFIG]
+    meta_path = user_defined_path or config.metadata_path()
+    if not meta_path:
+        raise ConfigError("Job metadata file path not provided.")
+    if not os.path.exists(meta_path):
+        raise ConfigError(f"Job metadata file not found: {meta_path}")
+    metadata_data = load_yaml(meta_path)
+    ctx.obj[METADATA] = metadata_data
+
     return metadata_data
 
 
+async def generate_outputs(ctx):
+    """Init and run output action."""
+    config = ctx.obj[CONFIG]
+    output_action = Output()
+    await output_action.init(
+        ctx.obj[PROV_CONFIG],
+        ctx.obj[METADATA],
+        ctx.obj[DB],
+        config.ansible_inventory_path(),
+        config.pytest_multihost_path(),
+    )
+    await output_action.generate_outputs()
+
+
 DB = "db"
 CONFIG = "config"
+PROV_CONFIG = "provconfig"
 METADATA = "metadata"
 
 
 @click.group()
-@click.option("-c", "--config", default="./provisioning-config.yaml")
-@click.option("-d", "--db", default="./.mrackdb.json")
+@click.option("-c", "--mrack-config", type=click.Path(exists=True))
+@click.option("-p", "--provisioning-config", type=click.Path(exists=True))
+@click.option("-d", "--db", type=click.Path(exists=True))
 @click.option("--debug", default=False, is_flag=True)
 @click.pass_context
-def mrackcli(ctx, config, db, debug):
+def mrackcli(ctx, mrack_config, provisioning_config, db, debug):
     """Multihost human friendly provisioner."""
     if debug:
         logging.getLogger("mrack").setLevel(logging.DEBUG)
 
+    config = MrackConfig(mrack_config)
+    config.load()
+    db_path = db or config.db_path("./.mrackdb.json")
+    p_config_path = provisioning_config or config.provisioning_config_path(
+        "./provisioning-config.yaml"
+    )
+
     init_providers()
     ctx.ensure_object(dict)
-    ctx.obj[DB] = init_db(db)
-    ctx.obj[CONFIG] = init_config(config)
+    ctx.obj[CONFIG] = config
+    ctx.obj[DB] = init_db(db_path)
+    ctx.obj[PROV_CONFIG] = init_prov_config(p_config_path)
 
 
 @mrackcli.command()
 @click.pass_context
-@click.argument("metadata")
+@click.option("-m", "--metadata", type=click.Path(exists=True))
 @click.option("-p", "--provider", default="openstack")
 @async_run
 async def up(ctx, metadata, provider):
@@ -114,38 +153,35 @@ async def up(ctx, metadata, provider):
 
     Based on provided job metadata file and provisioning configuration.
     """
-    ctx.obj[METADATA] = init_metadata(metadata)
+    init_metadata(ctx, metadata)
+
     up_action = Up()
-    await up_action.init(ctx.obj[CONFIG], ctx.obj[METADATA], provider, ctx.obj[DB])
+    await up_action.init(ctx.obj[PROV_CONFIG], ctx.obj[METADATA], provider, ctx.obj[DB])
     await up_action.provision()
 
-    output_action = Output()
-    await output_action.init(ctx.obj[CONFIG], ctx.obj[METADATA], ctx.obj[DB])
-    await output_action.generate_outputs()
+    await generate_outputs(ctx)
 
 
 @mrackcli.command()
 @click.pass_context
-@click.argument("metadata")
+@click.option("-m", "--metadata", type=click.Path(exists=True))
 @async_run
 async def destroy(ctx, metadata):
     """Destroy provisioned hosts."""
-    ctx.obj[METADATA] = init_metadata(metadata)
+    init_metadata(ctx, metadata)
     destroy_action = Destroy()
-    await destroy_action.init(ctx.obj[CONFIG], ctx.obj[METADATA], ctx.obj[DB])
+    await destroy_action.init(ctx.obj[PROV_CONFIG], ctx.obj[METADATA], ctx.obj[DB])
     await destroy_action.destroy()
 
 
 @mrackcli.command()
 @click.pass_context
-@click.argument("metadata")
+@click.option("-m", "--metadata", type=click.Path(exists=True))
 @async_run
 async def output(ctx, metadata):
     """Create outputs - such as Ansible inventory."""
-    ctx.obj[METADATA] = init_metadata(metadata)
-    output_action = Output()
-    await output_action.init(ctx.obj[CONFIG], ctx.obj[METADATA], ctx.obj[DB])
-    await output_action.generate_outputs()
+    init_metadata(ctx, metadata)
+    await generate_outputs(ctx)
 
 
 @mrackcli.command()
@@ -160,18 +196,40 @@ async def list(ctx):
 
 @mrackcli.command()
 @click.pass_context
-@click.argument("metadata", type=click.Path(exists=True))
 @click.argument("hostname", required=False)
+@click.option("-m", "--metadata", type=click.Path(exists=True))
 @async_run
-async def ssh(ctx, metadata, hostname):
+async def ssh(ctx, hostname, metadata):
     """SSH to host."""
-    ctx.obj[METADATA] = init_metadata(metadata)
-
+    init_metadata(ctx, metadata)
     ssh_action = SSH()
-    ssh_action.init(ctx.obj[CONFIG], ctx.obj[METADATA], ctx.obj[DB])
+    ssh_action.init(ctx.obj[PROV_CONFIG], ctx.obj[METADATA], ctx.obj[DB])
     ssh_action.ssh(hostname)
 
 
+@mrackcli.group()
+async def eh():
+    """Commands to update /etc/hosts file."""
+
+
+@eh.command()
+@click.pass_context
+@async_run
+async def add(ctx):
+    """Add active hosts to /etc/hosts file."""
+    eh_action = EtcHostsUpdate(ctx.obj[DB])
+    eh_action.update()
+
+
+@eh.command()
+@click.pass_context
+@async_run
+async def clear(ctx):
+    """Remove all mrack hosts from /etc/hosts file."""
+    eh_action = EtcHostsUpdate(ctx.obj[DB])
+    eh_action.clear()
+
+
 def exception_handler(func):
     """
     Top level exception handler.
@@ -190,6 +248,7 @@ def exception_handler(func):
             MetadataError,
             ValidationError,
             ProviderError,
+            ApplicationError,
         ) as known_error:
             logger.error(known_error)
             sys.exit(1)
